============
Contributing
============

Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given.

Submit Feedback
~~~~~~~~~~~~~~~

If you are proposing a feature:

* Explain in detail how it would work.
* Keep the scope as narrow as possible, to make it easier to implement.

Get Started!
------------

Ready to contribute? Here's how to set up `locationsharinglib` for local development.
Using of pipenv is highly recommended.

1. Clone your fork locally::

    $ git clone https://github.com/costastf/locationsharinglib

2. Install your local copy into a virtualenv. Assuming you have pipenv installed, this is how you set up your clone for local development::

    $ cd locationsharinglib/
    $ pipenv install --ignore-pipfile

3. Create a branch for local development::

    $ git checkout -b name-of-your-bugfix-or-feature

   Now you can make your changes locally.
   Do your development while using the CI capabilities and making sure the code passes lint, test, build and document stages.


4. Commit your changes and push your branch to the server::

    $ git add .
    $ git commit -m "Your detailed description of your changes."
    $ git push origin name-of-your-bugfix-or-feature

5. Submit a merge request
